==> piwigo_2.0.10.orig.tar.gz: piwigo-2.0.10/plugins/LocalFilesEditor/language/hu_HU/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based picture gallery                                  |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2009 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['locfiledit_onglet_localconf'] = 'Helyi beállítások';
$lang['locfiledit_onglet_css'] = 'CSS';
$lang['locfiledit_onglet_tpl'] = 'Sablonok';
$lang['locfiledit_onglet_lang'] = 'Nyelv';
$lang['locfiledit_onglet_plug'] = 'Egyedi Plugin';
$lang['locfiledit_cant_save'] = 'A fájl nem írható. Ellenőrizze a könyvtár "include/" írhatóságát (chmod)';
$lang['locfiledit_newfile'] = 'Nincs ilyen fájl a LocalFiles Editor létre tudja hozni';
$lang['locfiledit_save_config'] = 'A fájl módosítása sikeres.';
$lang['locfiledit_show_default'] = 'Fájl kiválasztás: ';
$lang['locfiledit_save_bak'] = 'Biztonsági másolat mentése.';
$lang['locfiledit_saved_bak'] = 'Biztonsági másolat létrehozva (%s)';
$lang['locfiledit_save_file'] = 'Fájl mentése';
$lang['locfiledit_choose_file'] = 'Válassza ki a szerkesztendő fájlt';
$lang['locfiledit_edit'] = 'Szerkesztés';
$lang['locfiledit_restore'] = 'Biztonsági másolat visszatöltése';
$lang['locfiledit_restore_confirm'] = 'Biztosan ezt akarja?
A változtatás nem vonható vissza.';
$lang['locfiledit_bak_loaded1'] = 'Biztonsági másolat betöltve.';
$lang['locfiledit_bak_loaded2'] = 'Mentett fájl visszaállítása.';
$lang['locfiledit_syntax_error'] = 'Syntax error! A fájl mentése meghiusult.';
$lang['locfiledit_enable_editarea'] = 'Szerkesztő megnyitása';
$lang['locfiledit_disable_editarea'] = 'Szerkesztő bezárása';
$lang['locfiledit_new_tpl'] = 'Új fájl létrehozása';
$lang['locfiledit_new_filename'] = 'Fájl neve';
$lang['locfiledit_model'] = 'Típus';
$lang['locfiledit_empty_page'] = 'Üres oldal';
$lang['locfiledit_parent_directory'] = 'Szülő könyvtár';
$lang['locfiledit_filename_error'] = 'Nem használható fájlnév vagy karakter.';
$lang['locfiledit_file_already_exists'] = 'Ilyen fájl már létezik.';
$lang['locfiledit_model_error'] = 'A típust ki kell választani.';
$lang['locfiledit_empty_filename'] = 'A fájlnevet ki kell tölteni.';

?>

==> piwigo_2.1.2.orig.tar.gz: piwigo-2.1.2/plugins/LocalFilesEditor/language/hu_HU/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based picture gallery                                  |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2010 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['locfiledit_onglet_localconf'] = 'Helyi beállítások';
$lang['locfiledit_onglet_css'] = 'CSS';
$lang['locfiledit_onglet_tpl'] = 'Sablonok';
$lang['locfiledit_onglet_lang'] = 'Nyelv';
$lang['locfiledit_onglet_plug'] = 'Egyedi bővítmény';
$lang['locfiledit_cant_save'] = 'Az fájl nem írható. Ellenőrizze a könyvtár "include/" írhatóságát (chmod)';
$lang['locfiledit_newfile'] = 'Nincs ilyen fájl a LocalFiles Editor létre tudja hozni';
$lang['locfiledit_save_config'] = 'A fájl módosítása sikeres.';
$lang['locfiledit_show_default'] = 'Fájl kiválasztás: ';
$lang['locfiledit_save_bak'] = 'Biztonsági másolat mentése.';
$lang['locfiledit_saved_bak'] = 'Biztonsági másolat létrehozva (%s)';
$lang['locfiledit_save_file'] = 'Fájl mentése';
$lang['locfiledit_choose_file'] = 'Válassza ki a szerkesztendő fájlt';
$lang['locfiledit_edit'] = 'Szerkesztés';
$lang['locfiledit_restore'] = 'Biztonsági másolat visszatöltése';
$lang['locfiledit_restore_confirm'] = 'Biztosan ezt akarja?
A változtatás nem vonható vissza.';
$lang['locfiledit_bak_loaded1'] = 'Biztonsági másolat betöltve.';
$lang['locfiledit_bak_loaded2'] = 'Mentett fájl visszaállítása.';
$lang['locfiledit_syntax_error'] = 'Syntax error! A fájl mentése meghiúsult.';
$lang['locfiledit_enable_editarea'] = 'Szerkesztő megnyitása';
$lang['locfiledit_disable_editarea'] = 'Szerkesztő bezárása';
$lang['locfiledit_new_tpl'] = 'Új fájl létrehozása';
$lang['locfiledit_new_filename'] = 'Fájl neve';
$lang['locfiledit_model'] = 'Típus';
$lang['locfiledit_empty_page'] = 'Üres oldal';
$lang['locfiledit_parent_directory'] = 'Szülő könyvtár';
$lang['locfiledit_filename_error'] = 'Nem használható fájlnév vagy karakter.';
$lang['locfiledit_file_already_exists'] = 'Ilyen fájl már létezik.';
$lang['locfiledit_model_error'] = 'A típust ki kell választani.';
$lang['locfiledit_empty_filename'] = 'A fájlnevet ki kell tölteni.';
/* TODO */ $lang['locfiledit_webmaster_only'] = 'Csak a webmesterek hozhatnak létre, vagy módosíthatnak helyi fájlokat.';

?>
